@@ -11,14 +11,11 @@
 #include <QTemporaryFile>
 #include <QImage>
 #include <QStandardPaths>
-#include <QString>
 #include <QThread>
 
 #include <KLocalizedString>
 
 #include "skanpage_debug.h"
-#include "DocumentSaver.h"
-#include "DocumentPrinter.h"
 
 struct PreviewPageProperties {
     double aspectRatio;
@@ -40,7 +37,6 @@ QDebug operator<<(QDebug d, const PreviewPageProperties& pageProperties)
 
 const static QString defaultFileName = i18n("New document");
 
-
 class DocumentModelPrivate
 {
 public:
@@ -62,14 +58,13 @@ DocumentModel::DocumentModel(QObject *parent)
     : QAbstractListModel(parent)
     , d(std::make_unique<DocumentModelPrivate>())
 {
-
 }
 
 DocumentModel::~DocumentModel()
 {
 }
 
-const QString DocumentModel::name() const
+QString DocumentModel::name() const
 {
     if (d->m_fileUrls.isEmpty()) {
         return i18n("New document");
@@ -80,6 +75,14 @@ const QString DocumentModel::name() const
     return d->m_fileUrls.first().fileName();
 }
 
+QString DocumentModel::fileName() const
+{
+    if (d->m_fileUrls.isEmpty() || d->m_fileUrls.count() > 1) {
+        return QString(i18n("New document") + QStringLiteral(".pdf"));
+    }
+    return d->m_fileUrls.first().fileName();
+}
+
 bool DocumentModel::changed() const
 {
     return d->m_changed;
@@ -130,10 +133,14 @@ void DocumentModel::createSharingFile(const QString &suffix, QList<int> pageNumb
          + QStringLiteral("/document.") + suffix);
     Q_EMIT saveDocument(temporaryLocation, selectPages(pageNumbers), SkanpageUtils::SharingDocument);
 }
-
-void DocumentModel::print()
+    
+void DocumentModel::exportPDF(const QUrl &fileUrl, const QString &title, const bool useOCR)
 {
-    Q_EMIT printDocument(d->m_pages);
+    if (useOCR) {
+        Q_EMIT saveDocument(fileUrl, d->m_pages, SkanpageUtils::OCRDocument, title);
+    } else {
+        Q_EMIT saveDocument(fileUrl, d->m_pages, SkanpageUtils::EntireDocument, title);
+    }
 }
 
 void DocumentModel::addImage(const QImage &image)
@@ -245,6 +252,44 @@ void DocumentModel::rotateImage(int row, RotateOption rotate)
     Q_EMIT dataChanged(index(row, 0), index(row, 0), {RotationAngleRole});
 }
 
+void DocumentModel::reorderPages(ReorderOption reorder)
+{
+    Q_EMIT layoutAboutToBeChanged();
+    if (reorder == Reverse) {
+        std::reverse(d->m_pages.begin(), d->m_pages.end());
+        std::reverse(d->m_details.begin(), d->m_details.end());
+    } else {
+        SkanpageUtils::DocumentPages newPages;
+        QList<PreviewPageProperties> newDetails;
+        newPages.reserve(d->m_pages.count());
+        newDetails.reserve(d->m_pages.count());
+        const int halfStart = d->m_pages.count() / 2;
+        const int oddOffset = d->m_pages.count() % 2;
+        if (reorder == ReorderDuplex) {
+            for (int i = 0; i < halfStart; i++) {
+                newPages.append(d->m_pages.at(i));
+                newPages.append(d->m_pages.at(i + halfStart + oddOffset));
+                newDetails.append(d->m_details.at(i));
+                newDetails.append(d->m_details.at(i + halfStart + oddOffset));
+            }
+        } else {
+            for (int i = 0; i < halfStart; i++) {
+                newPages.append(d->m_pages.at(i));
+                newPages.append(d->m_pages.at(d->m_pages.count() - 1 - i));
+                newDetails.append(d->m_details.at(i));
+                newDetails.append(d->m_details.at(d->m_details.count() - 1 - i));
+            }
+        }
+        if (oddOffset == 1) {
+            newPages.append(d->m_pages.at(halfStart));
+            newDetails.append(d->m_details.at(halfStart));
+        };
+        d->m_pages = newPages;
+        d->m_details = newDetails;
+    }
+    Q_EMIT layoutChanged();
+}
+
 void DocumentModel::removeImage(int row)
 {
     if (row < 0 || row >= d->m_pages.count()) {
